about summary refs log tree commit diff stats
path: root/src/config/files.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/config/files.c')
-rw-r--r--src/config/files.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/config/files.c b/src/config/files.c
index 75940c90..ed5697d8 100644
--- a/src/config/files.c
+++ b/src/config/files.c
@@ -5,20 +5,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  * Copyright (C) 2020 - 2023 Michael Vetter <jubalh@idoru.org>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -57,15 +57,15 @@ files_create_directories(void)
     gchar* xdg_data = _files_get_xdg_data_home();
 
     GString* themes_dir = g_string_new(xdg_config);
-    g_string_append(themes_dir, "/profanity/themes");
+    g_string_append(themes_dir, "/profani-tty/themes");
     GString* icons_dir = g_string_new(xdg_config);
-    g_string_append(icons_dir, "/profanity/icons");
+    g_string_append(icons_dir, "/profani-tty/icons");
     GString* chatlogs_dir = g_string_new(xdg_data);
-    g_string_append(chatlogs_dir, "/profanity/chatlogs");
+    g_string_append(chatlogs_dir, "/profani-tty/chatlogs");
     GString* logs_dir = g_string_new(xdg_data);
-    g_string_append(logs_dir, "/profanity/logs");
+    g_string_append(logs_dir, "/profani-tty/logs");
     GString* plugins_dir = g_string_new(xdg_data);
-    g_string_append(plugins_dir, "/profanity/plugins");
+    g_string_append(plugins_dir, "/profani-tty/plugins");
 
     if (!create_dir(themes_dir->str)) {
         log_error("Error while creating directory %s", themes_dir->str);
@@ -100,7 +100,7 @@ files_get_inputrc_file(void)
     GString* inputrc_file = g_string_new(xdg_config);
     g_free(xdg_config);
 
-    g_string_append(inputrc_file, "/profanity/inputrc");
+    g_string_append(inputrc_file, "/profani-tty/inputrc");
 
     if (g_file_test(inputrc_file->str, G_FILE_TEST_IS_REGULAR)) {
         gchar* result = g_strdup(inputrc_file->str);
@@ -130,7 +130,7 @@ files_get_log_file(const char* const log_file)
         logfile = g_string_new(log_file);
     } else {
         logfile = g_string_new(xdg_data);
-        g_string_append(logfile, "/profanity/logs/profanity");
+        g_string_append(logfile, "/profani-tty/logs/profani-tty");
 
         if (!prefs_get_boolean(PREF_LOG_SHARED)) {
             g_string_append_printf(logfile, "%d", getpid());
@@ -151,7 +151,7 @@ gchar*
 files_get_config_path(const char* const config_base)
 {
     gchar* xdg_config = _files_get_xdg_config_home();
-    gchar* result = g_strdup_printf("%s/profanity/%s", xdg_config, config_base);
+    gchar* result = g_strdup_printf("%s/profani-tty/%s", xdg_config, config_base);
     g_free(xdg_config);
     return result;
 }
@@ -160,7 +160,7 @@ gchar*
 files_get_data_path(const char* const data_base)
 {
     gchar* xdg_data = _files_get_xdg_data_home();
-    gchar* result = g_strdup_printf("%s/profanity/%s", xdg_data, data_base);
+    gchar* result = g_strdup_printf("%s/profani-tty/%s", xdg_data, data_base);
     g_free(xdg_data);
     return result;
 }
@@ -5,20 +5,20 @@
  * Copyright (C) 2020 - 2023 Michael Vetter <jubalh@idoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -5,20 +5,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -5,20 +5,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the